diff options
| author | Sébastien Theys <seb@odoo.com> | 2019-06-25 08:47:31 +0000 |
|---|---|---|
| committer | Sébastien Theys <seb@odoo.com> | 2019-06-25 08:47:31 +0000 |
| commit | 3e6bbe93af76120dd13aa162b1ae2d0c665eea06 (patch) | |
| tree | eb1564d5f835b4e6c46bb7ea8abeb4040c0acfa8 /addons/website_mass_mailing/static | |
| parent | 37a82e62a249315841408ad1cc9032c2c6ad20fa (diff) | |
[IMP] mail: call _get_tracked_fields in batch
Before this commit `_get_tracked_fields` was not called in batch because it took
the `updated_fields` parameter, but this parameter is not used.
By removing the parameter and calling the method in batch, creating 1000
products takes 20% less time.
Part of task-1918881
closes odoo/odoo#34347
Signed-off-by: Xavier Dollé (xdo) <xdo@odoo.com>
Diffstat (limited to 'addons/website_mass_mailing/static')
0 files changed, 0 insertions, 0 deletions
